PerfLensThemeData class

Constructors

PerfLensThemeData({required Color backgroundColor, required Color borderColor, required Color textColor, required Color iconColor, required Color warningColor, required Color successColor, required Color errorColor})
const

Properties

backgroundColor Color
final
borderColor Color
final
errorColor Color
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successColor Color
final
textColor Color
final
warningColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBrightness(Brightness brightness) PerfLensThemeData

Constants

dark → const PerfLensThemeData
light → const PerfLensThemeData